wlan: Ignore broadcast mac address to get connected staId.

Ignore broadcast mac address while fetching the connected
staId as it may result in fetching incorrect link speed.

Change-Id: I411ec34233b3e47b1fec967c540336133300a26d
CRs-Fixed: 547904
diff --git a/CORE/HDD/src/wlan_hdd_hostapd.c b/CORE/HDD/src/wlan_hdd_hostapd.c
index ac14932..309cef7 100644
--- a/CORE/HDD/src/wlan_hdd_hostapd.c
+++ b/CORE/HDD/src/wlan_hdd_hostapd.c
@@ -3652,10 +3652,10 @@
       hddLog(VOS_TRACE_LEVEL_ERROR, FL("String to Hex conversion Failed"));
    }
 
    /* If no mac address is passed and/or its length is less than 18,
     * link speed for first connected client will be returned.
     */
-   if (!VOS_IS_STATUS_SUCCESS(status ) || wrqu->data.length < 18)
+   if (!VOS_IS_STATUS_SUCCESS(status ) || wrqu->data.length < 17)
    {
       status = hdd_softap_GetConnectedStaId(pHostapdAdapter, (void *)(&staId));
    }
@@ -3652,10 +3652,10 @@
    }
 
-   /* If no mac address is passed and/or its length is less than 18,
+   /* If no mac address is passed and/or its length is less than 17,
     * link speed for first connected client will be returned.
     */